@@ -300,7 +300,9 @@ class client:
         )
         log.warning(msg)
 
-    def getDomainDisks(self, args: Namespace, vmConfig: str) -> List[DomainDisk]:
+    def getDomainDisks(  # pylint: disable=too-many-branches
+        self, args: Namespace, vmConfig: str
+    ) -> List[DomainDisk]:
         """Parse virtual machine configuration for disk devices, filter
         all unsupported or excluded devices
         """
@@ -348,6 +350,10 @@ class client:
                     self._hint(dev)
                     continue
                 diskPath = disk.xpath("source")[0].get("dev")
+            elif diskType == "network":
+                log.error("Unsupported network disk type for disk [%s]", dev)
+                self._hint(dev)
+                continue
             else:
                 log.error("Unable to detect disk volume type for disk [%s]", dev)
                 continue
